*************************************************************************
* Copyright 2012, Pericom Semiconductor Corporation                     *
* All Rights Reserved                                                   *
* CONFIDENTIAL INFORMATION -                                            *
* Pericom Semiconductor Corporation PROPRIETARY                         *
*************************************************************************

* PI3EQX7841 Transient Simulation

*******************************************************
$ Options, Models and Library
*******************************************************
.option post captab method=gear probe
.option gmindc=1e-13 gshdc=1e-13 runlvl=5
.option search='../PI3EQX7841/cells'

.prot
*******************************************************
$ Simulation Models
*******************************************************
.INC "../PI3EQX7841/lib/design.hspice"
.LIB "../PI3EQX7841/lib/model1.hspice" typical
.LIB "../PI3EQX7841/lib/model1.hspice" res_typical
.LIB "../PI3EQX7841/lib/model1.hspice" bjt_typical
.LIB "../PI3EQX7841/lib/model1.hspice" diode_typical
.LIB "../PI3EQX7841/lib/model1.hspice" moscap_typical
.LIB "../PI3EQX7841/lib/model1.hspice" mimcap_typical
.LIB "../PI3EQX7841/lib/model2.hspice" Def
.LIB "../PI3EQX7841/lib/model2.hspice" Typ_DNW
.LIB "../PI3EQX7841/lib/model2.hspice" diode_typical
.LIB "../PI3EQX7841/lib/model2.hspice" NMOSVAR_Typical
.LIB "../PI3EQX7841/lib/model2.hspice" MIM_Typical


*******************************************************
$ TL Model
*******************************************************
.MODEL model1_tl8 W MODELTYPE=RLGC, N=1
+ Lo = 2.55e-07
+ Co = 1.02e-10
+ Ro = 0.585
+ Rs = 2.5e-4
+ Gd = 2.85e-11
.unprot

.temp 90
vagnd	agnd	0	0

*************************************************************************
*** EQ and De-emp Settings 				
*************************************************************************
.param eq3v=0 eq2v=0 eq1v=power eq0v=0  $(equalizer setting)
.param sw1v=0 sw0v=0 				$(output swing)
.param de1v=0 de0v=power			$(output de-emphasis)


*******************************************************
$ Trace and Input
*******************************************************
.inc '../PI3EQX7841/prbs7.inc'

gtlinp  agnd inxp1b in agnd    '+0.5/50'
gtlinn  agnd inxn1b in agnd    '-0.5/50'
rtlinp  inxp1b agnd 50
rtlinn  inxn1b agnd 50

rinxp1a	inxp1a	0	50
rinxn1a	inxn1a	0	50
rinxp1c	inxp1c	0	50
rinxn1c	inxn1c	0	50

wlp1 N=1 inxp1a agnd inxp2a agnd fgd=8500meg RLGCmodel=model1_tl8 L='25.4mm*10'
wln1 N=1 inxn1a agnd inxn2a agnd fgd=8500meg RLGCmodel=model1_tl8 L='25.4mm*10'
wlp2 N=1 inxp1b agnd inxp2b agnd fgd=8500meg RLGCmodel=model1_tl8 L='25.4mm*10'
wln2 N=1 inxn1b agnd inxn2b agnd fgd=8500meg RLGCmodel=model1_tl8 L='25.4mm*10'
wlp3 N=1 inxp1c agnd inxp2c agnd fgd=8500meg RLGCmodel=model1_tl8 L='25.4mm*10'
wln3 N=1 inxn1c agnd inxn2c agnd fgd=8500meg RLGCmodel=model1_tl8 L='25.4mm*10'

cipa    inxp2a p1_in     100n
cina    inxn2a n1_in     100n
cipb    inxp2b p2_in     100n
cinb    inxn2b n2_in     100n
cipc    inxp2c p3_in     100n
cinc    inxn2c n3_in     100n
*******************************************************
$ ReDriver PI3EQX7841
*******************************************************
.inc '../PI3EQX7841/pi3eqx7841.inc'
xpi3eqx7841  p1_in n1_in p2_in n2_in p3_in n3_in p1_out n1_out p2_out n2_out p3_out n3_out 0 pi3eqx7841A

*******************************************************
$ Trace and Output
*******************************************************
copa p1_out outxp1a 100n
cona n1_out outxn1a 100n
copb p2_out outxp1b 100n
conb n2_out outxn1b 100n
copc p3_out outxp1c 100n
conc n3_out outxn1c 100n

wlp4 N=1 outxp1a agnd outpa agnd fgd=8500meg RLGCmodel=model1_tl8 L='25.4mm*6'
wln4 N=1 outxn1a agnd outna agnd fgd=8500meg RLGCmodel=model1_tl8 L='25.4mm*6'
wlp5 N=1 outxp1b agnd outpb agnd fgd=8500meg RLGCmodel=model1_tl8 L='25.4mm*6'
wln5 N=1 outxn1b agnd outnb agnd fgd=8500meg RLGCmodel=model1_tl8 L='25.4mm*6'
wlp6 N=1 outxp1c agnd outpc agnd fgd=8500meg RLGCmodel=model1_tl8 L='25.4mm*6'
wln6 N=1 outxn1c agnd outnc agnd fgd=8500meg RLGCmodel=model1_tl8 L='25.4mm*6'


ropa outpa agnd 50
rona outna agnd 50
ropb outpb agnd 50
ronb outnb agnd 50
ropc outpc agnd 50
ronc outnc agnd 50

.op 
.tran 'per2/20' 'per2*127+10n' start=10n

.probe v(in)
.probe v(inxp1b) v(inxn1b)	trace_in2=v(inxp1b inxn1b)	* middle channel input
.probe v(p2_in)  v(n2_in)	redrv_in2=v(p2_in n2_in)	* middle redriver input
.probe v(p2_out) v(n2_out)	redrv_out2=v(p2_out n2_out)	* middle redriver output
.probe v(outpb)  v(outnb)	trace_out2=v(outpb outnb)	* middle channel output

.probe tran ax=par('time-int(time/per2)*per2')
.param per2='1/5e9'  dtr='70p' dtf='70p' tdelay=0 amp=800m
.param power=3.3

.end
